<?php
	/*
		Plugin Name: VSF Simple Block
		Plugin URI: http://blog.v-s-f.co.uk/simple-block/
		Description: Allows you to select IP addresses, Hosts or Browser summary keywords via the simple block admin page to filter hits with.  Acts as a software firewall.  Please note that this plugin has the ability to block you if misused!  Please be very careful when using this plugin.  This plugin requires database rights to create tables and also create and run a stored procedure.  Without those database rights this plugin will not be able to function.
		Version: 0.2.1
		Author: Victoria Scales
		Author URI: http://www.v-s-f.co.uk
		Donation URI: http://www.amazon.co.uk/wishlist/2FRM957UJWLZ2
		Text Domain: vsf-simple-block
	*/
	
	/*
		Copyright 2011 Victoria Scales

		This program is free software; you can redistribute it and/or modify
		it under the terms of the GNU General Public License as published by
		the Free Software Foundation; either version 2 of the License, or
		(at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program; if not, see <http://www.gnu.org/licenses/>.
	*/
	
	
	define('VSF_BLOCK_DIR', dirname(__FILE__));
	define('VSF_BLOCK_DOMAIN', 'vsf-simple-block');
	define('VSF_BLOCK_DEBUG', false);
	
	include_once('vsf_simple_block_setup.php');
	include_once('vsf_simple_block_check.php');
	
	/**
	 * Utility class that contains functions that will be needed across the whole project.
	 * All functions are static.
	 * @author Victoria
	 */
	if( !class_exists("VSFBlockEssentials") )
	{
		class VSFBlockEssentials
		{
			public static function isNullOrBlank($stringToTest)
			{
				return is_null($stringToTest) || $stringToTest == "";
			}
			
			public static function log($log)
			{
				if ( VSF_BLOCK_DEBUG ) echo $log . "<br />";
			}
		}
	}
	
	// Export the xml file of the database filter table
	if ( isset($_POST['vsfBlockExportSettings']) )
	{
		$stringToTest = $_POST['vsfBlockExportSettings'];
		if (!(is_null($stringToTest) || $stringToTest == ""))
		{
			include('vsf_simple_block_export.php');
			$vsfSimpleBlockExport = new VSFSimpleBlockExport();
			$vsfSimpleBlockExport->generateExport();
		}
	}
	
	// Download the spidertrap.php file
	if ( isset($_POST['vsfBlockDownloadSpidertrap']) )
	{
		$stringToTest = $_POST['vsfBlockDownloadSpidertrap'];
		if (!(is_null($stringToTest) || $stringToTest == ""))
		{
			unset($_POST['vsfBlockDownloadSpidertrap']);
			unset($GLOBALS['vsfBlockDownloadSpidertrap']);
			
			include('vsf_simple_block_download_spidertrap.php');
			
			$dir_path = dirname(__FILE__) . DIRECTORY_SEPARATOR;
			
			if( false == ($fileContent = file_get_contents($dir_path . 'spidertrap.php')) )
			{
   				echo "Could not read spidertrap file.";
			}
			else
			{
				// replace the 4 required db values
				$fileContent = str_replace('*%DB_NAME%*', constant('DB_NAME'), $fileContent);
				$fileContent = str_replace('*%DB_USER%*', constant('DB_USER'), $fileContent);
				$fileContent = str_replace('*%DB_PASSWORD%*', constant('DB_PASSWORD'), $fileContent);
				$fileContent = str_replace('*%DB_HOST%*', constant('DB_HOST'), $fileContent);
				
				$vsfSimpleBlockDownloadSpidertrap = new VSFSimpleBlockDownloadSpidertrap();
				$vsfSimpleBlockDownloadSpidertrap->download($fileContent);
			}
		}
	}
	
	// create hook on the activation of the plugin so that the tables are created straight away!
	$obj = new BlockSetup();
	register_activation_hook(__FILE__, array($obj, 'activation'));
	
	add_action('admin_menu', array($obj, 'vsf_block_create_menu'));
	
	// will be run shortly after the plugin is loaded which is before most other wordpress features are done.
	$blockHit = new VSFBlockCheck();
	$blockHit->checkHit();

?>